@@ -7,7 +7,7 @@
 #![warn(clippy::pedantic)]
 #![deny(clippy::complexity)]
 #![deny(clippy::cognitive_complexity)]
-#![allow(clippy::needless_return)]
+#![allow(clippy::needless_return)] // To avoid surprise in devs more familiar where return is always explicit
 
 #![no_std]
 
@@ -28,7 +28,8 @@ pub mod c;
 #[inline]
 fn panic_if_null<T>(pointer: *const T) {
     if pointer.is_null() {
-        unreachable!("A null pointer was passed to the library, something is wrong in the C or C++ code");
+        log::error!("Trying to use a NULL pointer as a opaque pointer to Rust data");
+        unreachable!("Trying to use a NULL pointer as a opaque pointer to Rust data");
     }
 }
 
@@ -49,10 +50,12 @@ pub fn raw<T>(data: T) -> *mut T {
 #[cfg(any(feature = "alloc", feature = "std"))]
 #[inline]
 pub unsafe fn free<T>(pointer: *mut T) {
+    #[cfg(any(feature = "panic-if-null", debug_assertions))]
+    panic_if_null(pointer);
+    // TODO: decide if remove this try to avoid crash when free a null pointer
+    #[cfg(not(any(feature = "panic-if-null", debug_assertions)))]
     if pointer.is_null() {
-        #[cfg(debug_assertions)]
-        unreachable!("A null pointer was passed to the library, something is wrong in the C or C++ code");
-        #[cfg(not(debug_assertions))]
+        log::warn!("Trying to free a NULL pointer was ignored");
         return;
     }
     // CAUTION: this is unsafe
